@@ -6,7 +6,6 @@ from redis.exceptions import ConnectionError
 from rq import use_connection
 from rq.logutils import setup_loghandlers
 
-from django.conf import settings
 from django.core.management.base import BaseCommand
 from django.db import connections
 from django.utils.version import get_version
@@ -19,6 +18,34 @@ def reset_db_connections():
         c.close()
 
 
+def configure_sentry(sentry_dsn, **options):
+    """
+    Configure the Sentry client.
+
+    The **options kwargs are passed straight from the command
+    invocation - options relevant to Sentry configuration are
+    extracted.
+
+    In addition to the 'debug' and 'ca_certs' options, which can
+    be passed in as command options, we add the RqIntegration and
+    DjangoIntegration to the config.
+
+    Raises ImportError if the sentry_sdk is not available.
+
+    """
+    import sentry_sdk
+    sentry_options = {
+        'debug': options.get('sentry_debug', False),
+        'ca_certs': options.get('sentry_ca_certs', None),
+        'integrations': [
+            sentry_sdk.integrations.redis.RedisIntegration(),
+            sentry_sdk.integrations.rq.RqIntegration(),
+            sentry_sdk.integrations.django.DjangoIntegration()
+        ]
+    }
+    sentry_sdk.init(sentry_dsn, **sentry_options)
+
+
 class Command(BaseCommand):
     """
     Runs RQ workers on specified queues. Note that all queues passed into a
@@ -48,8 +75,12 @@ class Command(BaseCommand):
         parser.add_argument('--worker-ttl', action='store', type=int,
                             dest='worker_ttl', default=420,
                             help='Default worker timeout to be used')
-        parser.add_argument('--sentry-dsn', action='store', default=None, dest='sentry-dsn',
+        parser.add_argument('--sentry-dsn', action='store', default=None, dest='sentry_dsn',
                             help='Report exceptions to this Sentry DSN')
+        parser.add_argument('--sentry-ca-certs', action='store', default=None, dest='sentry_ca_certs',
+                            help='A path to an alternative CA bundle file in PEM-format')
+        parser.add_argument('--sentry-debug', action='store', default=False, dest='sentry_debug',
+                            help='Turns debug mode on or off.')
 
         if LooseVersion(get_version()) >= LooseVersion('1.10'):
             parser.add_argument('args', nargs='*', type=str,
@@ -60,9 +91,6 @@ class Command(BaseCommand):
         if pid:
             with open(os.path.expanduser(pid), "w") as fp:
                 fp.write(str(os.getpid()))
-        sentry_dsn = options.get('sentry-dsn')
-        if sentry_dsn is None:
-            sentry_dsn = getattr(settings, 'SENTRY_DSN', None)
 
         # Verbosity is defined by default in BaseCommand for all commands
         verbosity = options.get('verbosity')
@@ -74,6 +102,14 @@ class Command(BaseCommand):
             level = 'INFO'
         setup_loghandlers(level)
 
+        sentry_dsn = options.pop('sentry_dsn')
+        if sentry_dsn:
+            try:
+                configure_sentry(sentry_dsn, **options)
+            except ImportError:
+                self.stderr.write("Please install sentry-sdk using `pip install sentry-sdk`")
+                sys.exit(1)
+
         try:
             # Instantiate a worker
             worker_kwargs = {
@@ -91,15 +127,7 @@ class Command(BaseCommand):
             # Close any opened DB connection before any fork
             reset_db_connections()
 
-            if sentry_dsn:
-                try:
-                    from rq.contrib.sentry import register_sentry
-                    register_sentry(sentry_dsn)
-                except ImportError:
-                    self.stdout.write(self.style.ERROR("Please install sentry-sdk using `pip install sentry-sdk`"))
-                    sys.exit(1)
-
             w.work(burst=options.get('burst', False), with_scheduler=options.get('with_scheduler', False), logging_level=level)
         except ConnectionError as e:
-            print(e)
+            self.stderr.write(str(e))
             sys.exit(1)
